@@ -407,6 +407,9 @@ pub enum EventKind {
 
     /// To-device event kind.
     ToDevice,
+
+    /// Presence event kind.
+    Presence,
 }
 
 /// `HasDeserializeFields` is used in the code generated by the `Event` derive
